#!/usr/bin/env perl -w
#

use strict;

open XS, "< opengl_words.txt" or die "Could not read OpenGL constants: $!\n";
open CPP, "> gl_const.c"  or die "Could not open OpenGL file: $!\n";

print CPP <<HEADER;
#include <GL/gl.h>
#include <GL/glu.h>

int
main ( int argc, char **argv )
{
HEADER

my %words;

while (<XS>)
{
	chomp;
	print CPP qq|\tprintf( "$_\t%d\\n", $_ );\n|;
	$words{$_} = undef;
}

print CPP qq|}\n|;
close XS;
close CPP;

system( 'gcc -I/usr/X11R6/include/ -o gl_const gl_const.c' );

open GL, "./gl_const |" or die "Couldn't open gl_const: $!\n";

while (<GL>)
{
	chomp;
	my ($name, $value) = split(/\t/, $_);
	$words{ $name } = $value;
}

close GL;

for ( keys %words ) {
	print STDERR "Failed to find word $_" unless defined $words{$_};
}

open OGL, "> ../lib/SDL/OpenGL/Constants.pm";

print OGL <<HERE;
# SDL::OpenGL::Constants
#
# This is an autogenerated file, don't bother editing
#
# Copyright (C) 2003 David J. Goehrig <dave\@sdlperl.org>

package SDL::OpenGL::Constants;

use Exporter ();
use vars qw( \@ISA \@EXPORT );
\@ISA = 'Exporter';

HERE

my @export;

while (my ($constant, $value) = each %words)
{
	next unless defined $value;
	push @export, $constant;
	print OGL qq|sub $constant () { $value }\n|;
}

print OGL '@EXPORT = qw(', join( ' ', @export ), ');';
print OGL "\n1;\n";

# system("rm OpenGL.cx");
