#!/usr/bin/perl -w

use strict;

use File::Spec;
use File::Glob;

die "Usage:\n$0 <path_to_tutorial_files> <path_to_output_files>\n"
	unless @ARGV >= 2;

my $inpath  = shift;
my $index   = read_file( File::Spec->catfile( $inpath, 'Tutorial.pm' ));
my $path    = File::Spec->catdir( $inpath, 'Tutorial' );
my $outpath = shift;

my %names = (
	'SDL::Tutorial' => {
		name => 'SDL::Tutorial',
		link => 'http://sdl.perl.org/tutorials/',
		text => $index,
	},
);

for my $tutorial (glob("$path/*.pm"))
{
	my $text        = read_file( $tutorial );
	my ($name)      = $text =~ m/=head1 NAME\s+([\w:]+)\s+/s;
	(my $basename   = $tutorial) =~ s/.+\/(\w+)\.pm\z/$1/;
	$basename       = lc( $basename );
	my $link        = "http://sdl.perl.org/tutorials/$basename.html";

	$names{ $name } =
	{
		name => $name,
		link => $link,
		text => $text,
	};
}

while (my ($tutorial, $data) = each %names)
{
	(my $name  = $tutorial) =~ s/SDL::Tutorial(::)?//;
	$name    ||= 'index';
	$name      = lc( $name ) . '.pod';

	write_file(
		File::Spec->catfile( $outpath, $name ),
		link_names( $tutorial, $data->{text}, \%names )
	);
}

sub link_names
{
	my ($name, $text, $names) = @_;

	$text =~
		s/=item L<([:\w]+)>/
		"=item $names->{$1}{name} at L<$names->{$1}{link}>"
	/eg;

	return $text;
}

sub read_file
{
	my $filename       = shift;
	open my $file, '<', $filename or die "Cannot read '$filename': $!\n";
	my $contents       = do { local $/; <$file> };
	(undef, $contents) = split(/__END__\s+/, $contents, 2);
	return $contents;
}

sub write_file
{
	my ($filename, $text) = @_;
	open my $file, '>', $filename or die "Cannot write '$filename': $!\n";
	print $file $text;
}
